# Change Log

## [0.7.0](https://github.com/dldevinc/ajax-views/tree/v0.7.0) - 2023-12-20

### ⚠ BREAKING CHANGES

-   Dropped support for Python 3.6.
-   Dropped support for Django < 3.2.
-   Added support for Django 5.0.
-   Added support for Python 3.12.

## [0.6.1](https://github.com/dldevinc/ajax-views/tree/v0.6.1) - 2023-01-09

### Features

-   Add Python 3.11 support (no code changes were needed, but now we test this release).

## [0.6.0](https://github.com/dldevinc/ajax-views/tree/v0.6.0) - 2022-08-15

### Features

-   Added support for Django 4.1.

## [0.5.0](https://github.com/dldevinc/ajax-views/tree/v0.5.0) - 2022-05-28

### ⚠ BREAKING CHANGES

-   Dropped support for Python 3.5.

## [0.4.1](https://github.com/dldevinc/ajax-views/tree/v0.4.1) - 2021-02-08

-   Add typing
-   Improve tests
-   Add Python 3.9 support
-   Add Django 3.1 support

## [0.4.0](https://github.com/dldevinc/ajax-views/tree/v0.4.0) - 2020-07-14

-   Drop Python 3.4 support
-   Drop Django 1.8-1.10 support
